<?php

namespace Drupal\Tests\uc_cart\Functional;

use Drupal\Tests\uc_store\Functional\UbercartBrowserTestBase;

/**
 * Tests the checkout settings page.
 *
 * @group ubercart
 */
class CheckoutSettingsTest extends UbercartBrowserTestBase {

  /**
   * Tests enabling checkout functionality.
   */
  public function testEnableCheckout() {
    /** @var \Drupal\Tests\WebAssert $assert */
    $assert = $this->assertSession();

    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/store/config/checkout');
    // Check that enable checkout field exists.
    $assert->fieldExists('uc_checkout_enabled');

    $this->drupalGet('admin/store/config/checkout');
    $this->submitForm(['uc_checkout_enabled' => FALSE], 'Save configuration');

    $this->drupalGet('node/' . $this->product->id());
    $this->submitForm([], 'Add to cart');
    $assert->responseNotContains('Checkout');
    $buttons = $this->xpath('//input[@value="Checkout"]');
    $this->assertFalse(
      isset($buttons[0]),
      'The checkout button is not shown.'
    );
  }

  /**
   * Tests anonymous checkout functionality.
   */
  public function testAnonymousCheckout() {
    /** @var \Drupal\Tests\WebAssert $assert */
    $assert = $this->assertSession();

    $this->drupalLogin($this->adminUser);
    $this->drupalGet('admin/store/config/checkout');
    // Check that anonymous checkout field exists.
    $assert->fieldExists('uc_checkout_anonymous');

    $this->drupalGet('admin/store/config/checkout');
    $this->submitForm(['uc_checkout_anonymous' => FALSE], 'Save configuration');

    $this->drupalLogout();
    $this->drupalGet('node/' . $this->product->id());
    $this->submitForm([], 'Add to cart');
    $this->drupalGet('cart');
    $this->submitForm([], 'Checkout');
    // Tests that the checkout page is not displayed.
    $assert->pageTextNotContains('Enter your billing address and information here.');
  }

}
