<?php

namespace Drupal\Tests\uc_country\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests functionality of the extended CountryManager service.
 *
 * @group ubercart
 */
class CountryManagerTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['uc_country'];

  /**
   * Test overriding the core Drupal country_manager service.
   */
  public function testServiceOverride() {
    $country_manager = \Drupal::service('country_manager');

    /*
     * Test core Drupal country_manager functions.
     */

    // getList(): Verify that all Drupal-provided countries
    // were imported without error.
    $this->assertCount(258, $country_manager->getList(), '258 core Drupal countries found');

    /*
     * Test new functions provided by this extended service.
     */

    // getAvailableList(): Verify that all Ubercart-provided countries
    // are available.
    $this->assertCount(248, $country_manager->getAvailableList(), '248 Ubercart countries found');

    // getEnabledList(): Verify that no countries are enabled by default.
    $this->assertCount(0, $country_manager->getEnabledList(), 'No Ubercart countries enabled by default');

    // getCountry(): Verify the basic get country function works and
    // returns a valid config entity.
    $country_manager->getCountry('US')->setStatus(TRUE)->save();

    // getByProperty(): Verify we can obtain country entities by property.
    $this->assertCount(1, $country_manager->getByProperty(['status' => TRUE]), 'One country enabled by default');

    // getZoneList(): Verify that CA has 13 zones.
    $this->assertCount(13, $country_manager->getZoneList('CA'), 'Canada has 13 zones');

    // @todo Compare getList() to core getStandardList().
    // @todo Test standard list alter, to make sure we don't break contrib.
  }

}
